all.Tacms<-function(){
     cat("\n")
     note_for_Tacss_input()
     cat("\n")
     note_for_close_window()
     TacMSpar<-data.frame(subject=c(1,2),Hem=c(0),Alb=c(0),Dil=c(0),Flu=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     TacMSpar<-edit(TacMSpar)
##     TacMSpar<-ymscheck(TacMSpar)
     cat("\n")
     Tac.ms(length(TacMSpar$subject),TacMSpar$c,TacMSpar$tau,TacMSpar$ts,TacMSpar$D,TacMSpar$Hem,TacMSpar$Alb,TacMSpar$Dil,TacMSpar$Flu)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Tacss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Taccpr(4.5,TacMSpar$D,TacMSpar$tau,TacMSpar$ts)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mcg/mL)")
     output1<-coutput
     show(coutput)
     C<-Taccpr(4.5,TacMSpar$D,TacMSpar$tau,TacMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mcg/mL)")
     output2<-coutput
     show(coutput)    
     cat("\n") 
     cal.again()
}